@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -25,6 +25,7 @@
 # (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 # SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
+
 import os
 
 from .printer import Printer
@@ -72,7 +73,18 @@ class CLICommand(object):
 
             Printer.raise_error(error_message)
 
-        (fetcher, parent, objects) = fetcher.fetch(filter=args.filter, query_parameters=query_parameters)
+        if hasattr(args, 'page_size') and args.page_size > 0:
+            (fetcher, parent, objects) = fetcher.fetch(filter=args.filter, query_parameters=query_parameters, page=args.page, page_size=args.page_size)
+        else: 
+            page = 0
+            (fetcher, parent, objects) = fetcher.fetch(filter=args.filter, query_parameters=query_parameters, page=page)
+            if objects is not None and len(objects) > 0:
+                while True:
+                    page += 1
+                    (fetcher, parent, tmp_objects) = fetcher.fetch(filter=args.filter, query_parameters=query_parameters, page=page)
+                    if tmp_objects is None or len(tmp_objects) == 0:
+                        break
+                    objects += tmp_objects
 
         if objects is None:
             Printer.raise_error("Could not retrieve. Activate verbose mode for more information")
