@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,17 +27,12 @@
 
 
 
+
 from .fetchers import NUMetadatasFetcher
 
 
 from .fetchers import NUGlobalMetadatasFetcher
 
-
-from .fetchers import NUJobsFetcher
-
-
-from .fetchers import NUStatisticsFetcher
-
 from bambou import NURESTObject
 
 
@@ -45,7 +40,7 @@ class NUEgressAdvFwdEntryTemplate(NURESTObject):
     """ Represents a EgressAdvFwdEntryTemplate in the VSD
 
         Notes:
-            Defines the template of Egress Advanced Forwarding entries
+            Egress forwarding policy rules define what action to take for a particular type of traffic, based on its origin, destination, protocol, EtherType, ports, DSCP value and other information. Supported actions are to redirect traffic, change the forwarding class of the traffic or to allow traffic to pass untouched.
     """
 
     __rest_name__ = "egressadvfwdentrytemplate"
@@ -104,6 +99,8 @@ class NUEgressAdvFwdEntryTemplate(NURESTObject):
     
     CONST_FC_OVERRIDE_A = "A"
     
+    CONST_ASSOCIATED_TRAFFIC_TYPE_L4_SERVICE_GROUP = "L4_SERVICE_GROUP"
+    
     CONST_NETWORK_TYPE_UNDERLAY_INTERNET_POLICYGROUP = "UNDERLAY_INTERNET_POLICYGROUP"
     
     CONST_FC_OVERRIDE_H = "H"
@@ -116,20 +113,22 @@ class NUEgressAdvFwdEntryTemplate(NURESTObject):
     
     CONST_FAILSAFE_DATAPATH_FAIL_TO_BLOCK = "FAIL_TO_BLOCK"
     
-    CONST_LOCATION_TYPE_VPORTTAG = "VPORTTAG"
-    
     CONST_LOCATION_TYPE_SUBNET = "SUBNET"
     
     CONST_UPLINK_PREFERENCE_SECONDARY = "SECONDARY"
     
     CONST_POLICY_STATE_DRAFT = "DRAFT"
     
-    CONST_LOCATION_TYPE_REDIRECTIONTARGET = "REDIRECTIONTARGET"
+    CONST_ASSOCIATED_TRAFFIC_TYPE_L4_SERVICE = "L4_SERVICE"
+    
+    CONST_WEB_FILTER_TYPE_WEB_DOMAIN_NAME = "WEB_DOMAIN_NAME"
     
     CONST_POLICY_STATE_LIVE = "LIVE"
     
     CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
     
+    CONST_WEB_FILTER_TYPE_WEB_CATEGORY = "WEB_CATEGORY"
+    
     CONST_UPLINK_PREFERENCE_PRIMARY = "PRIMARY"
     
     CONST_NETWORK_TYPE_PGEXPRESSION = "PGEXPRESSION"
@@ -168,10 +167,11 @@ class NUEgressAdvFwdEntryTemplate(NURESTObject):
         self._ipv6_address_override = None
         self._dscp = None
         self._failsafe_datapath = None
-        self._name = None
         self._last_updated_by = None
         self._action = None
         self._address_override = None
+        self._web_filter_id = None
+        self._web_filter_type = None
         self._redirect_vport_tag_id = None
         self._description = None
         self._destination_port = None
@@ -190,22 +190,26 @@ class NUEgressAdvFwdEntryTemplate(NURESTObject):
         self._priority = None
         self._protocol = None
         self._associated_live_entity_id = None
+        self._associated_live_template_id = None
+        self._associated_traffic_type = None
+        self._associated_traffic_type_id = None
         self._stats_id = None
         self._stats_logging_enabled = None
         self._ether_type = None
         self._external_id = None
         
-        self.expose_attribute(local_name="acl_template_name", remote_name="ACLTemplateName", attribute_type=str, is_required=True, is_unique=False)
+        self.expose_attribute(local_name="acl_template_name", remote_name="ACLTemplateName", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="icmp_code", remote_name="ICMPCode", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="icmp_type", remote_name="ICMPType", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="fc_override", remote_name="FCOverride", attribute_type=str, is_required=False, is_unique=False, choices=[u'A', u'B', u'C', u'D', u'E', u'F', u'G', u'H', u'NONE'])
         self.expose_attribute(local_name="ipv6_address_override", remote_name="IPv6AddressOverride", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="dscp", remote_name="DSCP", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="failsafe_datapath", remote_name="failsafeDatapath", attribute_type=str, is_required=False, is_unique=False, choices=[u'FAIL_TO_BLOCK', u'FAIL_TO_WIRE'])
-        self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="action", remote_name="action", attribute_type=str, is_required=True, is_unique=False, choices=[u'DROP', u'FORWARD', u'REDIRECT'])
         self.expose_attribute(local_name="address_override", remote_name="addressOverride", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="web_filter_id", remote_name="webFilterID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="web_filter_type", remote_name="webFilterType", attribute_type=str, is_required=False, is_unique=False, choices=[u'WEB_CATEGORY', u'WEB_DOMAIN_NAME'])
         self.expose_attribute(local_name="redirect_vport_tag_id", remote_name="redirectVPortTagID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="destination_port", remote_name="destinationPort", attribute_type=str, is_required=False, is_unique=False)
@@ -213,10 +217,10 @@ class NUEgressAdvFwdEntryTemplate(NURESTObject):
         self.expose_attribute(local_name="network_type", remote_name="networkType", attribute_type=str, is_required=False, is_unique=False, choices=[u'ANY', u'ENDPOINT_DOMAIN', u'ENDPOINT_SUBNET', u'ENDPOINT_ZONE', u'ENTERPRISE_NETWORK', u'INTERNET_POLICYGROUP', u'NETWORK_MACRO_GROUP', u'PGEXPRESSION', u'POLICYGROUP', u'PUBLIC_NETWORK', u'SUBNET', u'UNDERLAY_INTERNET_POLICYGROUP', u'ZONE'])
         self.expose_attribute(local_name="mirror_destination_id", remote_name="mirrorDestinationID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="flow_logging_enabled", remote_name="flowLoggingEnabled", attribute_type=bool, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="enterprise_name", remote_name="enterpriseName", attribute_type=str, is_required=True, is_unique=False)
+        self.expose_attribute(local_name="enterprise_name", remote_name="enterpriseName", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="location_id", remote_name="locationID", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="location_type", remote_name="locationType", attribute_type=str, is_required=True, is_unique=False, choices=[u'ANY', u'PGEXPRESSION', u'POLICYGROUP', u'REDIRECTIONTARGET', u'SUBNET', u'VPORTTAG', u'ZONE'])
+        self.expose_attribute(local_name="location_type", remote_name="locationType", attribute_type=str, is_required=True, is_unique=False, choices=[u'ANY', u'PGEXPRESSION', u'POLICYGROUP', u'SUBNET', u'ZONE'])
         self.expose_attribute(local_name="policy_state", remote_name="policyState", attribute_type=str, is_required=False, is_unique=False, choices=[u'DRAFT', u'LIVE'])
         self.expose_attribute(local_name="domain_name", remote_name="domainName", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="source_port", remote_name="sourcePort", attribute_type=str, is_required=False, is_unique=False)
@@ -224,6 +228,9 @@ class NUEgressAdvFwdEntryTemplate(NURESTObject):
         self.expose_attribute(local_name="priority", remote_name="priority", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="protocol", remote_name="protocol", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_live_entity_id", remote_name="associatedLiveEntityID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_live_template_id", remote_name="associatedLiveTemplateID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_traffic_type", remote_name="associatedTrafficType", attribute_type=str, is_required=False, is_unique=False, choices=[u'L4_SERVICE', u'L4_SERVICE_GROUP'])
+        self.expose_attribute(local_name="associated_traffic_type_id", remote_name="associatedTrafficTypeID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="stats_id", remote_name="statsID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="stats_logging_enabled", remote_name="statsLoggingEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="ether_type", remote_name="etherType", attribute_type=str, is_required=True, is_unique=False)
@@ -238,12 +245,6 @@ class NUEgressAdvFwdEntryTemplate(NURESTObject):
         
         self.global_metadatas = NUGlobalMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
-        
-        self.jobs = NUJobsFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
-        self.statistics = NUStatisticsFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
 
         self._compute_args(**kwargs)
 
@@ -438,29 +439,6 @@ class NUEgressAdvFwdEntryTemplate(NURESTObject):
         self._failsafe_datapath = value
 
     
-    @property
-    def name(self):
-        """ Get name value.
-
-            Notes:
-                Name of the policy
-
-                
-        """
-        return self._name
-
-    @name.setter
-    def name(self, value):
-        """ Set name value.
-
-            Notes:
-                Name of the policy
-
-                
-        """
-        self._name = value
-
-    
     @property
     def last_updated_by(self):
         """ Get last_updated_by value.
@@ -538,6 +516,60 @@ class NUEgressAdvFwdEntryTemplate(NURESTObject):
         self._address_override = value
 
     
+    @property
+    def web_filter_id(self):
+        """ Get web_filter_id value.
+
+            Notes:
+                ID of web filter category or web domain name entity used
+
+                
+                This attribute is named `webFilterID` in VSD API.
+                
+        """
+        return self._web_filter_id
+
+    @web_filter_id.setter
+    def web_filter_id(self, value):
+        """ Set web_filter_id value.
+
+            Notes:
+                ID of web filter category or web domain name entity used
+
+                
+                This attribute is named `webFilterID` in VSD API.
+                
+        """
+        self._web_filter_id = value
+
+    
+    @property
+    def web_filter_type(self):
+        """ Get web_filter_type value.
+
+            Notes:
+                Indicates type of web filter being set
+
+                
+                This attribute is named `webFilterType` in VSD API.
+                
+        """
+        return self._web_filter_type
+
+    @web_filter_type.setter
+    def web_filter_type(self, value):
+        """ Set web_filter_type value.
+
+            Notes:
+                Indicates type of web filter being set
+
+                
+                This attribute is named `webFilterType` in VSD API.
+                
+        """
+        self._web_filter_type = value
+
+    
     @property
     def redirect_vport_tag_id(self):
         """ Get redirect_vport_tag_id value.
@@ -1012,6 +1044,87 @@ class NUEgressAdvFwdEntryTemplate(NURESTObject):
         self._associated_live_entity_id = value
 
     
+    @property
+    def associated_live_template_id(self):
+        """ Get associated_live_template_id value.
+
+            Notes:
+                In the draft mode, the ACL entity refers to this live entity parent. In non-drafted mode, this is null
+
+                
+                This attribute is named `associatedLiveTemplateID` in VSD API.
+                
+        """
+        return self._associated_live_template_id
+
+    @associated_live_template_id.setter
+    def associated_live_template_id(self, value):
+        """ Set associated_live_template_id value.
+
+            Notes:
+                In the draft mode, the ACL entity refers to this live entity parent. In non-drafted mode, this is null
+
+                
+                This attribute is named `associatedLiveTemplateID` in VSD API.
+                
+        """
+        self._associated_live_template_id = value
+
+    
+    @property
+    def associated_traffic_type(self):
+        """ Get associated_traffic_type value.
+
+            Notes:
+                The associated Traffic type. L4 Service / L4 Service Group
+
+                
+                This attribute is named `associatedTrafficType` in VSD API.
+                
+        """
+        return self._associated_traffic_type
+
+    @associated_traffic_type.setter
+    def associated_traffic_type(self, value):
+        """ Set associated_traffic_type value.
+
+            Notes:
+                The associated Traffic type. L4 Service / L4 Service Group
+
+                
+                This attribute is named `associatedTrafficType` in VSD API.
+                
+        """
+        self._associated_traffic_type = value
+
+    
+    @property
+    def associated_traffic_type_id(self):
+        """ Get associated_traffic_type_id value.
+
+            Notes:
+                The associated Traffic Type ID
+
+                
+                This attribute is named `associatedTrafficTypeID` in VSD API.
+                
+        """
+        return self._associated_traffic_type_id
+
+    @associated_traffic_type_id.setter
+    def associated_traffic_type_id(self, value):
+        """ Set associated_traffic_type_id value.
+
+            Notes:
+                The associated Traffic Type ID
+
+                
+                This attribute is named `associatedTrafficTypeID` in VSD API.
+                
+        """
+        self._associated_traffic_type_id = value
+
+    
     @property
     def stats_id(self):
         """ Get stats_id value.
