@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,7 @@
 
 
 
+
 from .fetchers import NUMetadatasFetcher
 
 
@@ -54,21 +55,29 @@ class NUGroup(NURESTObject):
     
     ## Constants
     
+    CONST_ROLE_ADMINOPERATOR = "ADMINOPERATOR"
+    
+    CONST_ROLE_NETCONFMGR = "NETCONFMGR"
+    
     CONST_MANAGEMENT_MODE_CMS = "CMS"
     
+    CONST_ROLE_ORGNETWORKDESIGNER = "ORGNETWORKDESIGNER"
+    
     CONST_ROLE_CMS = "CMS"
     
     CONST_ROLE_UNKNOWN = "UNKNOWN"
     
+    CONST_ROLE_PREACTIVATION = "PREACTIVATION"
+    
     CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
     
-    CONST_ROLE_ORGNETWORKDESIGNER = "ORGNETWORKDESIGNER"
+    CONST_ROLE_STATS = "STATS"
     
     CONST_ROLE_CSPOPERATOR = "CSPOPERATOR"
     
     CONST_ROLE_USER = "USER"
     
-    CONST_ROLE_ORGAPPDESIGNER = "ORGAPPDESIGNER"
+    CONST_MANAGEMENT_MODE_RESERVED = "RESERVED"
     
     CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
     
@@ -80,6 +89,10 @@ class NUGroup(NURESTObject):
     
     CONST_ROLE_SYSTEM = "SYSTEM"
     
+    CONST_ROLE_POSTACTIVATION = "POSTACTIVATION"
+    
+    CONST_ROLE_SECURITYADMINISTRATOR = "SECURITYADMINISTRATOR"
+    
     CONST_ROLE_ORGADMIN = "ORGADMIN"
     
     CONST_MANAGEMENT_MODE_DEFAULT = "DEFAULT"
@@ -117,13 +130,13 @@ class NUGroup(NURESTObject):
         
         self.expose_attribute(local_name="ldap_group_dn", remote_name="LDAPGroupDN", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
-        self.expose_attribute(local_name="management_mode", remote_name="managementMode", attribute_type=str, is_required=False, is_unique=False, choices=[u'CMS', u'DEFAULT'])
+        self.expose_attribute(local_name="management_mode", remote_name="managementMode", attribute_type=str, is_required=False, is_unique=False, choices=[u'CMS', u'DEFAULT', u'RESERVED'])
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="account_restrictions", remote_name="accountRestrictions", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="restriction_date", remote_name="restrictionDate", attribute_type=float, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
-        self.expose_attribute(local_name="role", remote_name="role", attribute_type=str, is_required=False, is_unique=False, choices=[u'CMS', u'CSPOPERATOR', u'CSPROOT', u'JMS', u'ORGADMIN', u'ORGAPPDESIGNER', u'ORGNETWORKDESIGNER', u'ORGUSER', u'SYSTEM', u'UNKNOWN', u'USER'])
+        self.expose_attribute(local_name="role", remote_name="role", attribute_type=str, is_required=False, is_unique=False, choices=[u'ADMINOPERATOR', u'CMS', u'CSPOPERATOR', u'CSPROOT', u'JMS', u'NETCONFMGR', u'ORGADMIN', u'ORGNETWORKDESIGNER', u'ORGUSER', u'POSTACTIVATION', u'PREACTIVATION', u'SECURITYADMINISTRATOR', u'STATS', u'SYSTEM', u'UNKNOWN', u'USER'])
         self.expose_attribute(local_name="private", remote_name="private", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         
