@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,7 @@
 
 
 
+
 from .fetchers import NUMetadatasFetcher
 
 
@@ -39,7 +40,7 @@ class NUInfrastructureGatewayProfile(NURESTObject):
     """ Represents a InfrastructureGatewayProfile in the VSD
 
         Notes:
-            Represents Infrastructure Gateway Profile
+            Infrastructure Gateway Profiles are gateway-level platform attributes inherited by gateways as they are instantiated, connecting them to Nuage management infrastructure.
     """
 
     __rest_name__ = "infrastructuregatewayprofile"
@@ -48,27 +49,23 @@ class NUInfrastructureGatewayProfile(NURESTObject):
     
     ## Constants
     
-    CONST_REMOTE_LOG_MODE_SCP = "SCP"
+    CONST_UPGRADE_ACTION_DOWNLOAD_AND_UPGRADE_NOW = "DOWNLOAD_AND_UPGRADE_NOW"
     
     CONST_CONTROLLER_LESS_FORWARDING_MODE_LOCAL_AND_REMOTE = "LOCAL_AND_REMOTE"
     
-    CONST_UPGRADE_ACTION_NONE = "NONE"
+    CONST_UPGRADE_ACTION_UPGRADE_AT_BOOTSTRAPPING = "UPGRADE_AT_BOOTSTRAPPING"
     
     CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
     
     CONST_REMOTE_LOG_MODE_RSYSLOG = "RSYSLOG"
     
-    CONST_UPGRADE_ACTION_DOWNLOAD_AND_UPGRADE_NOW = "DOWNLOAD_AND_UPGRADE_NOW"
-    
     CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
     
     CONST_CONTROLLER_LESS_FORWARDING_MODE_DISABLED = "DISABLED"
     
     CONST_REMOTE_LOG_MODE_DISABLED = "DISABLED"
     
-    CONST_UPGRADE_ACTION_UPGRADE_AT_BOOTSTRAPPING = "UPGRADE_AT_BOOTSTRAPPING"
-    
-    CONST_REMOTE_LOG_MODE_SFTP = "SFTP"
+    CONST_UPGRADE_ACTION_NONE = "NONE"
     
     CONST_UPGRADE_ACTION_DOWNLOAD_ONLY = "DOWNLOAD_ONLY"
     
@@ -104,6 +101,8 @@ class NUInfrastructureGatewayProfile(NURESTObject):
         self._datapath_sync_timeout = None
         self._dead_timer = None
         self._dead_timer_enabled = None
+        self._web_filter_download_port = None
+        self._web_filter_query_port = None
         self._remote_log_mode = None
         self._remote_log_server_address = None
         self._remote_log_server_port = None
@@ -127,12 +126,14 @@ class NUInfrastructureGatewayProfile(NURESTObject):
         
         self.expose_attribute(local_name="ntp_server_key", remote_name="NTPServerKey", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="ntp_server_key_id", remote_name="NTPServerKeyID", attribute_type=int, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
+        self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=True)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="datapath_sync_timeout", remote_name="datapathSyncTimeout", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="dead_timer", remote_name="deadTimer", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="dead_timer_enabled", remote_name="deadTimerEnabled", attribute_type=bool, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="remote_log_mode", remote_name="remoteLogMode", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'RSYSLOG', u'SCP', u'SFTP'])
+        self.expose_attribute(local_name="web_filter_download_port", remote_name="webFilterDownloadPort", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="web_filter_query_port", remote_name="webFilterQueryPort", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="remote_log_mode", remote_name="remoteLogMode", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'RSYSLOG'])
         self.expose_attribute(local_name="remote_log_server_address", remote_name="remoteLogServerAddress", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="remote_log_server_port", remote_name="remoteLogServerPort", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
@@ -199,7 +200,7 @@ class NUInfrastructureGatewayProfile(NURESTObject):
         """ Get ntp_server_key_id value.
 
             Notes:
-                Correspond to the key ID on the NTP server that matches the ntpServerKey value.  Valid values are from 1 to 255 as specified by SR-OS and 0 to specify unused (VSD/NSG only).
+                Corresponds to the key ID on the NTP server that matches the NTPServerKey value.  Valid values are from 1 to 255 as specified by SR-OS and when value 0 is entered, it means that the NTP Key is not used (VSD/NSG only).
 
                 
                 This attribute is named `NTPServerKeyID` in VSD API.
@@ -212,7 +213,7 @@ class NUInfrastructureGatewayProfile(NURESTObject):
         """ Set ntp_server_key_id value.
 
             Notes:
-                Correspond to the key ID on the NTP server that matches the ntpServerKey value.  Valid values are from 1 to 255 as specified by SR-OS and 0 to specify unused (VSD/NSG only).
+                Corresponds to the key ID on the NTP server that matches the NTPServerKey value.  Valid values are from 1 to 255 as specified by SR-OS and when value 0 is entered, it means that the NTP Key is not used (VSD/NSG only).
 
                 
                 This attribute is named `NTPServerKeyID` in VSD API.
@@ -303,7 +304,7 @@ class NUInfrastructureGatewayProfile(NURESTObject):
         """ Get dead_timer value.
 
             Notes:
-                ISO 8601 format duration: **P nYnMnD T nHnMnS**. **P** represents the period field and **T** the time field. Period field: **Y** = year, **M** = month, **D** = day. Time field: **H** = hours, **M** = minutes, **S** = seconds. **n** is the value of each field. Because the years and month are units that vary in length, for the time being those are not supported yet.
+                ISO 8601 format duration: **PnYnMnD T nHnMnS**. **P** represents the period field and **T** the time field. Period field: **Y** = year, **M** = month, **D** = day. Time field: **H** = hours, **M** = minutes, **S** = seconds. **n** is the value of each field. Because the years and month are units that vary in length, for the time being those are not supported yet.
 
                 
                 This attribute is named `deadTimer` in VSD API.
@@ -316,7 +317,7 @@ class NUInfrastructureGatewayProfile(NURESTObject):
         """ Set dead_timer value.
 
             Notes:
-                ISO 8601 format duration: **P nYnMnD T nHnMnS**. **P** represents the period field and **T** the time field. Period field: **Y** = year, **M** = month, **D** = day. Time field: **H** = hours, **M** = minutes, **S** = seconds. **n** is the value of each field. Because the years and month are units that vary in length, for the time being those are not supported yet.
+                ISO 8601 format duration: **PnYnMnD T nHnMnS**. **P** represents the period field and **T** the time field. Period field: **Y** = year, **M** = month, **D** = day. Time field: **H** = hours, **M** = minutes, **S** = seconds. **n** is the value of each field. Because the years and month are units that vary in length, for the time being those are not supported yet.
 
                 
                 This attribute is named `deadTimer` in VSD API.
@@ -352,6 +353,60 @@ class NUInfrastructureGatewayProfile(NURESTObject):
         self._dead_timer_enabled = value
 
     
+    @property
+    def web_filter_download_port(self):
+        """ Get web_filter_download_port value.
+
+            Notes:
+                The port to be opened by the proxy for webfilter update database
+
+                
+                This attribute is named `webFilterDownloadPort` in VSD API.
+                
+        """
+        return self._web_filter_download_port
+
+    @web_filter_download_port.setter
+    def web_filter_download_port(self, value):
+        """ Set web_filter_download_port value.
+
+            Notes:
+                The port to be opened by the proxy for webfilter update database
+
+                
+                This attribute is named `webFilterDownloadPort` in VSD API.
+                
+        """
+        self._web_filter_download_port = value
+
+    
+    @property
+    def web_filter_query_port(self):
+        """ Get web_filter_query_port value.
+
+            Notes:
+                The port to be opened by the proxy for webfilter category query request
+
+                
+                This attribute is named `webFilterQueryPort` in VSD API.
+                
+        """
+        return self._web_filter_query_port
+
+    @web_filter_query_port.setter
+    def web_filter_query_port(self, value):
+        """ Set web_filter_query_port value.
+
+            Notes:
+                The port to be opened by the proxy for webfilter category query request
+
+                
+                This attribute is named `webFilterQueryPort` in VSD API.
+                
+        """
+        self._web_filter_query_port = value
+
+    
     @property
     def remote_log_mode(self):
         """ Get remote_log_mode value.
@@ -596,7 +651,7 @@ class NUInfrastructureGatewayProfile(NURESTObject):
         """ Get controller_less_enabled value.
 
             Notes:
-                Flag to enable controller-less operations.
+                Flag to enable controller-less operations
 
                 
                 This attribute is named `controllerLessEnabled` in VSD API.
@@ -609,7 +664,7 @@ class NUInfrastructureGatewayProfile(NURESTObject):
         """ Set controller_less_enabled value.
 
             Notes:
-                Flag to enable controller-less operations.
+                Flag to enable controller-less operations
 
                 
                 This attribute is named `controllerLessEnabled` in VSD API.
@@ -704,7 +759,7 @@ class NUInfrastructureGatewayProfile(NURESTObject):
         """ Get open_flow_audit_timer value.
 
             Notes:
-                Openflow audit timer in sec. Upon the expiry of this timer a set of cleanup operations will be performed
+                Openflow audit timer in seconds. Upon the expiry of this timer a set of cleanup operations will be performed
 
                 
                 This attribute is named `openFlowAuditTimer` in VSD API.
@@ -717,7 +772,7 @@ class NUInfrastructureGatewayProfile(NURESTObject):
         """ Set open_flow_audit_timer value.
 
             Notes:
-                Openflow audit timer in sec. Upon the expiry of this timer a set of cleanup operations will be performed
+                Openflow audit timer in seconds. Upon the expiry of this timer a set of cleanup operations will be performed
 
                 
                 This attribute is named `openFlowAuditTimer` in VSD API.
@@ -812,7 +867,7 @@ class NUInfrastructureGatewayProfile(NURESTObject):
         """ Get stats_collector_port value.
 
             Notes:
-                The port to open by the proxy for stats collector to use
+                The port to open by the proxy for the statistics collector to use.
 
                 
                 This attribute is named `statsCollectorPort` in VSD API.
@@ -825,7 +880,7 @@ class NUInfrastructureGatewayProfile(NURESTObject):
         """ Set stats_collector_port value.
 
             Notes:
-                The port to open by the proxy for stats collector to use
+                The port to open by the proxy for the statistics collector to use.
 
                 
                 This attribute is named `statsCollectorPort` in VSD API.
@@ -866,7 +921,7 @@ class NUInfrastructureGatewayProfile(NURESTObject):
         """ Get system_sync_scheduler value.
 
             Notes:
-                Time in a Cron format when configuration update are being applied on the Gateway (NSG).  This property is linked to systemSyncWindow.  Default value is every midnight (0 0 * * *).  Format:  Minutes Hours DayOfMonth Month DayOfWeek
+                Time, in a Cron format, when configuration updates are being applied on the Gateway (NSG).  This property is linked to systemSyncWindow.  Default value is every midnight (0 0 * * *).  Format:  Minutes Hours DayOfMonth Month DayOfWeek
 
                 
                 This attribute is named `systemSyncScheduler` in VSD API.
@@ -879,7 +934,7 @@ class NUInfrastructureGatewayProfile(NURESTObject):
         """ Set system_sync_scheduler value.
 
             Notes:
-                Time in a Cron format when configuration update are being applied on the Gateway (NSG).  This property is linked to systemSyncWindow.  Default value is every midnight (0 0 * * *).  Format:  Minutes Hours DayOfMonth Month DayOfWeek
+                Time, in a Cron format, when configuration updates are being applied on the Gateway (NSG).  This property is linked to systemSyncWindow.  Default value is every midnight (0 0 * * *).  Format:  Minutes Hours DayOfMonth Month DayOfWeek
 
                 
                 This attribute is named `systemSyncScheduler` in VSD API.
