@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,15 +27,13 @@
 
 
 
+
 from .fetchers import NUMetadatasFetcher
 
 
 from .fetchers import NUGlobalMetadatasFetcher
 
 
-from .fetchers import NUJobsFetcher
-
-
 from .fetchers import NUStatisticsFetcher
 
 from bambou import NURESTObject
@@ -45,7 +43,7 @@ class NUIngressACLEntryTemplate(NURESTObject):
     """ Represents a IngressACLEntryTemplate in the VSD
 
         Notes:
-            Defines the template of Ingress ACL entries
+            Security Policy Entries defines what action to take for a particular type of traffic, based on its origin and its destination, its protocol, EtherType, eventual ports, DSCP value and other information.
     """
 
     __rest_name__ = "ingressaclentrytemplate"
@@ -60,8 +58,6 @@ class NUIngressACLEntryTemplate(NURESTObject):
     
     CONST_LOCATION_TYPE_ZONE = "ZONE"
     
-    CONST_ACTION_REDIRECT = "REDIRECT"
-    
     CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
     
     CONST_NETWORK_TYPE_PUBLIC_NETWORK = "PUBLIC_NETWORK"
@@ -88,9 +84,11 @@ class NUIngressACLEntryTemplate(NURESTObject):
     
     CONST_ASSOCIATED_TRAFFIC_TYPE_L4_SERVICE_GROUP = "L4_SERVICE_GROUP"
     
-    CONST_NETWORK_TYPE_ENDPOINT_SUBNET = "ENDPOINT_SUBNET"
+    CONST_NETWORK_TYPE_UNDERLAY_INTERNET_POLICYGROUP = "UNDERLAY_INTERNET_POLICYGROUP"
     
-    CONST_LOCATION_TYPE_VPORTTAG = "VPORTTAG"
+    CONST_NETWORK_TYPE_SAAS_APPLICATION_GROUP = "SAAS_APPLICATION_GROUP"
+    
+    CONST_NETWORK_TYPE_ENDPOINT_SUBNET = "ENDPOINT_SUBNET"
     
     CONST_LOCATION_TYPE_SUBNET = "SUBNET"
     
@@ -98,15 +96,15 @@ class NUIngressACLEntryTemplate(NURESTObject):
     
     CONST_ASSOCIATED_TRAFFIC_TYPE_L4_SERVICE = "L4_SERVICE"
     
-    CONST_LOCATION_TYPE_REDIRECTIONTARGET = "REDIRECTIONTARGET"
+    CONST_WEB_FILTER_TYPE_WEB_DOMAIN_NAME = "WEB_DOMAIN_NAME"
     
     CONST_POLICY_STATE_LIVE = "LIVE"
     
     CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
     
-    CONST_NETWORK_TYPE_PGEXPRESSION = "PGEXPRESSION"
+    CONST_WEB_FILTER_TYPE_WEB_CATEGORY = "WEB_CATEGORY"
     
-    CONST_NETWORK_TYPE_INTERNET_POLICYGROUP = "INTERNET_POLICYGROUP"
+    CONST_NETWORK_TYPE_PGEXPRESSION = "PGEXPRESSION"
     
     CONST_NETWORK_TYPE_ENDPOINT_ZONE = "ENDPOINT_ZONE"
     
@@ -137,6 +135,8 @@ class NUIngressACLEntryTemplate(NURESTObject):
         self._last_updated_by = None
         self._action = None
         self._address_override = None
+        self._web_filter_id = None
+        self._web_filter_type = None
         self._description = None
         self._destination_port = None
         self._network_id = None
@@ -154,8 +154,10 @@ class NUIngressACLEntryTemplate(NURESTObject):
         self._protocol = None
         self._associated_l7_application_signature_id = None
         self._associated_live_entity_id = None
+        self._associated_live_template_id = None
         self._associated_traffic_type = None
         self._associated_traffic_type_id = None
+        self._associated_virtual_firewall_rule_id = None
         self._stateful = None
         self._stats_id = None
         self._stats_logging_enabled = None
@@ -169,18 +171,20 @@ class NUIngressACLEntryTemplate(NURESTObject):
         self.expose_attribute(local_name="ipv6_address_override", remote_name="IPv6AddressOverride", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="dscp", remote_name="DSCP", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="action", remote_name="action", attribute_type=str, is_required=True, is_unique=False, choices=[u'DROP', u'FORWARD', u'REDIRECT'])
+        self.expose_attribute(local_name="action", remote_name="action", attribute_type=str, is_required=True, is_unique=False, choices=[u'DROP', u'FORWARD'])
         self.expose_attribute(local_name="address_override", remote_name="addressOverride", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="web_filter_id", remote_name="webFilterID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="web_filter_type", remote_name="webFilterType", attribute_type=str, is_required=False, is_unique=False, choices=[u'WEB_CATEGORY', u'WEB_DOMAIN_NAME'])
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="destination_port", remote_name="destinationPort", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="network_id", remote_name="networkID", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="network_type", remote_name="networkType", attribute_type=str, is_required=False, is_unique=False, choices=[u'ANY', u'ENDPOINT_DOMAIN', u'ENDPOINT_SUBNET', u'ENDPOINT_ZONE', u'ENTERPRISE_NETWORK', u'INTERNET_POLICYGROUP', u'NETWORK_MACRO_GROUP', u'PGEXPRESSION', u'POLICYGROUP', u'PUBLIC_NETWORK', u'SUBNET', u'ZONE'])
+        self.expose_attribute(local_name="network_type", remote_name="networkType", attribute_type=str, is_required=False, is_unique=False, choices=[u'ANY', u'ENDPOINT_DOMAIN', u'ENDPOINT_SUBNET', u'ENDPOINT_ZONE', u'ENTERPRISE_NETWORK', u'NETWORK_MACRO_GROUP', u'PGEXPRESSION', u'POLICYGROUP', u'PUBLIC_NETWORK', u'SAAS_APPLICATION_GROUP', u'SUBNET', u'UNDERLAY_INTERNET_POLICYGROUP', u'ZONE'])
         self.expose_attribute(local_name="mirror_destination_id", remote_name="mirrorDestinationID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="flow_logging_enabled", remote_name="flowLoggingEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="enterprise_name", remote_name="enterpriseName", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="location_id", remote_name="locationID", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="location_type", remote_name="locationType", attribute_type=str, is_required=True, is_unique=False, choices=[u'ANY', u'PGEXPRESSION', u'POLICYGROUP', u'REDIRECTIONTARGET', u'SUBNET', u'VPORTTAG', u'ZONE'])
+        self.expose_attribute(local_name="location_type", remote_name="locationType", attribute_type=str, is_required=True, is_unique=False, choices=[u'ANY', u'PGEXPRESSION', u'POLICYGROUP', u'SUBNET', u'ZONE'])
         self.expose_attribute(local_name="policy_state", remote_name="policyState", attribute_type=str, is_required=False, is_unique=False, choices=[u'DRAFT', u'LIVE'])
         self.expose_attribute(local_name="domain_name", remote_name="domainName", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="source_port", remote_name="sourcePort", attribute_type=str, is_required=False, is_unique=False)
@@ -188,8 +192,10 @@ class NUIngressACLEntryTemplate(NURESTObject):
         self.expose_attribute(local_name="protocol", remote_name="protocol", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_l7_application_signature_id", remote_name="associatedL7ApplicationSignatureID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_live_entity_id", remote_name="associatedLiveEntityID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_live_template_id", remote_name="associatedLiveTemplateID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_traffic_type", remote_name="associatedTrafficType", attribute_type=str, is_required=False, is_unique=False, choices=[u'L4_SERVICE', u'L4_SERVICE_GROUP'])
         self.expose_attribute(local_name="associated_traffic_type_id", remote_name="associatedTrafficTypeID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_virtual_firewall_rule_id", remote_name="associatedVirtualFirewallRuleID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="stateful", remote_name="stateful", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="stats_id", remote_name="statsID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="stats_logging_enabled", remote_name="statsLoggingEnabled", attribute_type=bool, is_required=False, is_unique=False)
@@ -207,9 +213,6 @@ class NUIngressACLEntryTemplate(NURESTObject):
         self.global_metadatas = NUGlobalMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
-        self.jobs = NUJobsFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
         self.statistics = NUStatisticsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
 
@@ -429,6 +432,60 @@ class NUIngressACLEntryTemplate(NURESTObject):
         self._address_override = value
 
     
+    @property
+    def web_filter_id(self):
+        """ Get web_filter_id value.
+
+            Notes:
+                ID of web filter category or web domain name entity used
+
+                
+                This attribute is named `webFilterID` in VSD API.
+                
+        """
+        return self._web_filter_id
+
+    @web_filter_id.setter
+    def web_filter_id(self, value):
+        """ Set web_filter_id value.
+
+            Notes:
+                ID of web filter category or web domain name entity used
+
+                
+                This attribute is named `webFilterID` in VSD API.
+                
+        """
+        self._web_filter_id = value
+
+    
+    @property
+    def web_filter_type(self):
+        """ Get web_filter_type value.
+
+            Notes:
+                Indicates type of web filter being set
+
+                
+                This attribute is named `webFilterType` in VSD API.
+                
+        """
+        return self._web_filter_type
+
+    @web_filter_type.setter
+    def web_filter_type(self, value):
+        """ Set web_filter_type value.
+
+            Notes:
+                Indicates type of web filter being set
+
+                
+                This attribute is named `webFilterType` in VSD API.
+                
+        """
+        self._web_filter_type = value
+
+    
     @property
     def description(self):
         """ Get description value.
@@ -876,12 +933,39 @@ class NUIngressACLEntryTemplate(NURESTObject):
         self._associated_live_entity_id = value
 
     
+    @property
+    def associated_live_template_id(self):
+        """ Get associated_live_template_id value.
+
+            Notes:
+                In the draft mode, the ACL entity refers to this live entity parent. In non-drafted mode, this is null
+
+                
+                This attribute is named `associatedLiveTemplateID` in VSD API.
+                
+        """
+        return self._associated_live_template_id
+
+    @associated_live_template_id.setter
+    def associated_live_template_id(self, value):
+        """ Set associated_live_template_id value.
+
+            Notes:
+                In the draft mode, the ACL entity refers to this live entity parent. In non-drafted mode, this is null
+
+                
+                This attribute is named `associatedLiveTemplateID` in VSD API.
+                
+        """
+        self._associated_live_template_id = value
+
+    
     @property
     def associated_traffic_type(self):
         """ Get associated_traffic_type value.
 
             Notes:
-                This property reflects the type of traffic in case an ACL entry is created using an L4 Service or L4 Service Group. In case a protocol and port are specified for the ACL entry, this property has to be empty (null). Supported values are L4_SERVICE, L4_SERVICE_GROUP and empty.
+                This property reflects the type of traffic in case an ACL entry is created using an Service or Service Group. In case a protocol and port are specified for the ACL entry, this property has to be empty (null). Supported values are L4_SERVICE, L4_SERVICE_GROUP and empty.
 
                 
                 This attribute is named `associatedTrafficType` in VSD API.
@@ -894,7 +978,7 @@ class NUIngressACLEntryTemplate(NURESTObject):
         """ Set associated_traffic_type value.
 
             Notes:
-                This property reflects the type of traffic in case an ACL entry is created using an L4 Service or L4 Service Group. In case a protocol and port are specified for the ACL entry, this property has to be empty (null). Supported values are L4_SERVICE, L4_SERVICE_GROUP and empty.
+                This property reflects the type of traffic in case an ACL entry is created using an Service or Service Group. In case a protocol and port are specified for the ACL entry, this property has to be empty (null). Supported values are L4_SERVICE, L4_SERVICE_GROUP and empty.
 
                 
                 This attribute is named `associatedTrafficType` in VSD API.
@@ -908,7 +992,7 @@ class NUIngressACLEntryTemplate(NURESTObject):
         """ Get associated_traffic_type_id value.
 
             Notes:
-                If a traffic type is specified as L4 Service or Service Group, then the associated Id of  Service / Service Group should be specifed here
+                If a traffic type is specified as Service or Service Group, then the associated Id of  Service / Service Group should be specifed here
 
                 
                 This attribute is named `associatedTrafficTypeID` in VSD API.
@@ -921,7 +1005,7 @@ class NUIngressACLEntryTemplate(NURESTObject):
         """ Set associated_traffic_type_id value.
 
             Notes:
-                If a traffic type is specified as L4 Service or Service Group, then the associated Id of  Service / Service Group should be specifed here
+                If a traffic type is specified as Service or Service Group, then the associated Id of  Service / Service Group should be specifed here
 
                 
                 This attribute is named `associatedTrafficTypeID` in VSD API.
@@ -930,6 +1014,33 @@ class NUIngressACLEntryTemplate(NURESTObject):
         self._associated_traffic_type_id = value
 
     
+    @property
+    def associated_virtual_firewall_rule_id(self):
+        """ Get associated_virtual_firewall_rule_id value.
+
+            Notes:
+                The ID of the Virtual Firewall Rule, if this was derived as part of the Virtual Firewall Rule creation
+
+                
+                This attribute is named `associatedVirtualFirewallRuleID` in VSD API.
+                
+        """
+        return self._associated_virtual_firewall_rule_id
+
+    @associated_virtual_firewall_rule_id.setter
+    def associated_virtual_firewall_rule_id(self, value):
+        """ Set associated_virtual_firewall_rule_id value.
+
+            Notes:
+                The ID of the Virtual Firewall Rule, if this was derived as part of the Virtual Firewall Rule creation
+
+                
+                This attribute is named `associatedVirtualFirewallRuleID` in VSD API.
+                
+        """
+        self._associated_virtual_firewall_rule_id = value
+
+    
     @property
     def stateful(self):
         """ Get stateful value.
