@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,7 @@
 
 
 
+
 from .fetchers import NUL2DomainsFetcher
 
 
@@ -42,9 +43,18 @@ from .fetchers import NUPermissionsFetcher
 from .fetchers import NUMetadatasFetcher
 
 
+from .fetchers import NUPGExpressionTemplatesFetcher
+
+
 from .fetchers import NUEgressACLTemplatesFetcher
 
 
+from .fetchers import NUEgressAdvFwdTemplatesFetcher
+
+
+from .fetchers import NUVirtualFirewallPoliciesFetcher
+
+
 from .fetchers import NUGlobalMetadatasFetcher
 
 
@@ -54,9 +64,6 @@ from .fetchers import NUIngressACLTemplatesFetcher
 from .fetchers import NUIngressAdvFwdTemplatesFetcher
 
 
-from .fetchers import NUIngressExternalServiceTemplatesFetcher
-
-
 from .fetchers import NUJobsFetcher
 
 
@@ -71,6 +78,9 @@ from .fetchers import NUGroupsFetcher
 
 from .fetchers import NUEventLogsFetcher
 
+
+from .fetchers import NUOverlayMirrorDestinationTemplatesFetcher
+
 from bambou import NURESTObject
 
 
@@ -78,7 +88,7 @@ class NUL2DomainTemplate(NURESTObject):
     """ Represents a L2DomainTemplate in the VSD
 
         Notes:
-            L2 Domain in VSD as derived by templates. This object describes the L2 Domain template.
+            An L2 Domain is a distributed logical switch that enables L2 communication. An L2 Domain template is a model that can be instantiated as often as required, thereby creating real, functioning L2 Domains.
     """
 
     __rest_name__ = "l2domaintemplate"
@@ -119,8 +129,12 @@ class NUL2DomainTemplate(NURESTObject):
     
     CONST_IP_TYPE_DUALSTACK = "DUALSTACK"
     
+    CONST_ENTITY_STATE_MARKED_FOR_DELETION = "MARKED_FOR_DELETION"
+    
     CONST_POLICY_CHANGE_STATUS_APPLIED = "APPLIED"
     
+    CONST_ENTITY_STATE_UNDER_CONSTRUCTION = "UNDER_CONSTRUCTION"
+    
     
 
     def __init__(self, **kwargs):
@@ -143,38 +157,44 @@ class NUL2DomainTemplate(NURESTObject):
         self._dhcp_managed = None
         self._dpi = None
         self._ip_type = None
+        self._ipv6_address = None
+        self._ipv6_gateway = None
         self._name = None
         self._last_updated_by = None
         self._gateway = None
-        self._gateway_mac_address = None
         self._address = None
         self._description = None
         self._netmask = None
         self._encryption = None
         self._entity_scope = None
+        self._entity_state = None
         self._policy_change_status = None
         self._use_global_mac = None
         self._associated_multicast_channel_map_id = None
         self._multicast = None
         self._external_id = None
+        self._dynamic_ipv6_address = None
         
         self.expose_attribute(local_name="dhcp_managed", remote_name="DHCPManaged", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="dpi", remote_name="DPI", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'INHERITED'])
         self.expose_attribute(local_name="ip_type", remote_name="IPType", attribute_type=str, is_required=False, is_unique=False, choices=[u'DUALSTACK', u'IPV4'])
+        self.expose_attribute(local_name="ipv6_address", remote_name="IPv6Address", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="ipv6_gateway", remote_name="IPv6Gateway", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="gateway", remote_name="gateway", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="gateway_mac_address", remote_name="gatewayMACAddress", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="address", remote_name="address", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="netmask", remote_name="netmask", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="encryption", remote_name="encryption", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED'])
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
+        self.expose_attribute(local_name="entity_state", remote_name="entityState", attribute_type=str, is_required=False, is_unique=False, choices=[u'MARKED_FOR_DELETION', u'UNDER_CONSTRUCTION'])
         self.expose_attribute(local_name="policy_change_status", remote_name="policyChangeStatus", attribute_type=str, is_required=False, is_unique=False, choices=[u'APPLIED', u'DISCARDED', u'STARTED'])
         self.expose_attribute(local_name="use_global_mac", remote_name="useGlobalMAC", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED'])
         self.expose_attribute(local_name="associated_multicast_channel_map_id", remote_name="associatedMulticastChannelMapID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="multicast", remote_name="multicast", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'INHERITED'])
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
+        self.expose_attribute(local_name="dynamic_ipv6_address", remote_name="dynamicIpv6Address", attribute_type=bool, is_required=False, is_unique=False)
         
 
         # Fetchers
@@ -195,9 +215,18 @@ class NUL2DomainTemplate(NURESTObject):
         self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.pg_expression_templates = NUPGExpressionTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.egress_acl_templates = NUEgressACLTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.egress_adv_fwd_templates = NUEgressAdvFwdTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.virtual_firewall_policies = NUVirtualFirewallPoliciesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.global_metadatas = NUGlobalMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -207,9 +236,6 @@ class NUL2DomainTemplate(NURESTObject):
         self.ingress_adv_fwd_templates = NUIngressAdvFwdTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
-        self.ingress_external_service_templates = NUIngressExternalServiceTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
         self.jobs = NUJobsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -224,6 +250,9 @@ class NUL2DomainTemplate(NURESTObject):
         
         self.event_logs = NUEventLogsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
+        
+        self.overlay_mirror_destination_templates = NUOverlayMirrorDestinationTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
 
         self._compute_args(**kwargs)
 
@@ -310,6 +339,60 @@ class NUL2DomainTemplate(NURESTObject):
         self._ip_type = value
 
     
+    @property
+    def ipv6_address(self):
+        """ Get ipv6_address value.
+
+            Notes:
+                IPV6 address of the route - Optional
+
+                
+                This attribute is named `IPv6Address` in VSD API.
+                
+        """
+        return self._ipv6_address
+
+    @ipv6_address.setter
+    def ipv6_address(self, value):
+        """ Set ipv6_address value.
+
+            Notes:
+                IPV6 address of the route - Optional
+
+                
+                This attribute is named `IPv6Address` in VSD API.
+                
+        """
+        self._ipv6_address = value
+
+    
+    @property
+    def ipv6_gateway(self):
+        """ Get ipv6_gateway value.
+
+            Notes:
+                The IPv6 address of the gateway of this subnet
+
+                
+                This attribute is named `IPv6Gateway` in VSD API.
+                
+        """
+        return self._ipv6_gateway
+
+    @ipv6_gateway.setter
+    def ipv6_gateway(self, value):
+        """ Set ipv6_gateway value.
+
+            Notes:
+                The IPv6 address of the gateway of this subnet
+
+                
+                This attribute is named `IPv6Gateway` in VSD API.
+                
+        """
+        self._ipv6_gateway = value
+
+    
     @property
     def name(self):
         """ Get name value.
@@ -383,33 +466,6 @@ class NUL2DomainTemplate(NURESTObject):
         self._gateway = value
 
     
-    @property
-    def gateway_mac_address(self):
-        """ Get gateway_mac_address value.
-
-            Notes:
-                gateway MAC address for a managed l2 domain
-
-                
-                This attribute is named `gatewayMACAddress` in VSD API.
-                
-        """
-        return self._gateway_mac_address
-
-    @gateway_mac_address.setter
-    def gateway_mac_address(self, value):
-        """ Set gateway_mac_address value.
-
-            Notes:
-                gateway MAC address for a managed l2 domain
-
-                
-                This attribute is named `gatewayMACAddress` in VSD API.
-                
-        """
-        self._gateway_mac_address = value
-
-    
     @property
     def address(self):
         """ Get address value.
@@ -529,6 +585,33 @@ class NUL2DomainTemplate(NURESTObject):
         self._entity_scope = value
 
     
+    @property
+    def entity_state(self):
+        """ Get entity_state value.
+
+            Notes:
+                Intermediate State of L2 Domain.
+
+                
+                This attribute is named `entityState` in VSD API.
+                
+        """
+        return self._entity_state
+
+    @entity_state.setter
+    def entity_state(self, value):
+        """ Set entity_state value.
+
+            Notes:
+                Intermediate State of L2 Domain.
+
+                
+                This attribute is named `entityState` in VSD API.
+                
+        """
+        self._entity_state = value
+
+    
     @property
     def policy_change_status(self):
         """ Get policy_change_status value.
@@ -660,6 +743,33 @@ class NUL2DomainTemplate(NURESTObject):
         self._external_id = value
 
     
+    @property
+    def dynamic_ipv6_address(self):
+        """ Get dynamic_ipv6_address value.
+
+            Notes:
+                Turn on or off dynamic allocation of IPV6 address
+
+                
+                This attribute is named `dynamicIpv6Address` in VSD API.
+                
+        """
+        return self._dynamic_ipv6_address
+
+    @dynamic_ipv6_address.setter
+    def dynamic_ipv6_address(self, value):
+        """ Set dynamic_ipv6_address value.
+
+            Notes:
+                Turn on or off dynamic allocation of IPV6 address
+
+                
+                This attribute is named `dynamicIpv6Address` in VSD API.
+                
+        """
+        self._dynamic_ipv6_address = value
+
+    
 
     
     ## Custom methods
