@@ -31,6 +31,9 @@
 from .fetchers import NUDeploymentFailuresFetcher
 
 
+from .fetchers import NUPermissionsFetcher
+
+
 from .fetchers import NUMetadatasFetcher
 
 
@@ -80,9 +83,11 @@ class NUEgressProfile(NURESTObject):
         
         self._name = None
         self._last_updated_by = None
+        self._last_updated_date = None
         self._description = None
         self._embedded_metadata = None
         self._entity_scope = None
+        self._creation_date = None
         self._assoc_entity_type = None
         self._associated_ip_filter_profile_id = None
         self._associated_ip_filter_profile_name = None
@@ -92,13 +97,17 @@ class NUEgressProfile(NURESTObject):
         self._associated_mac_filter_profile_name = None
         self._associated_sap_egress_qo_s_profile_id = None
         self._associated_sap_egress_qo_s_profile_name = None
+        self._customer_id = None
+        self._owner = None
         self._external_id = None
         
-        self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="last_updated_date", remote_name="lastUpdatedDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="embedded_metadata", remote_name="embeddedMetadata", attribute_type=list, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
+        self.expose_attribute(local_name="creation_date", remote_name="creationDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="assoc_entity_type", remote_name="assocEntityType", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_ip_filter_profile_id", remote_name="associatedIPFilterProfileID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_ip_filter_profile_name", remote_name="associatedIPFilterProfileName", attribute_type=str, is_required=False, is_unique=False)
@@ -108,6 +117,8 @@ class NUEgressProfile(NURESTObject):
         self.expose_attribute(local_name="associated_mac_filter_profile_name", remote_name="associatedMACFilterProfileName", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_sap_egress_qo_s_profile_id", remote_name="associatedSAPEgressQoSProfileID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_sap_egress_qo_s_profile_name", remote_name="associatedSAPEgressQoSProfileName", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="customer_id", remote_name="customerID", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="owner", remote_name="owner", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         
 
@@ -117,6 +128,9 @@ class NUEgressProfile(NURESTObject):
         self.deployment_failures = NUDeploymentFailuresFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.permissions = NUPermissionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -180,6 +194,33 @@ class NUEgressProfile(NURESTObject):
         self._last_updated_by = value
 
     
+    @property
+    def last_updated_date(self):
+        """ Get last_updated_date value.
+
+            Notes:
+                Time stamp when this object was last updated.
+
+                
+                This attribute is named `lastUpdatedDate` in VSD API.
+                
+        """
+        return self._last_updated_date
+
+    @last_updated_date.setter
+    def last_updated_date(self, value):
+        """ Set last_updated_date value.
+
+            Notes:
+                Time stamp when this object was last updated.
+
+                
+                This attribute is named `lastUpdatedDate` in VSD API.
+                
+        """
+        self._last_updated_date = value
+
+    
     @property
     def description(self):
         """ Get description value.
@@ -257,6 +298,33 @@ class NUEgressProfile(NURESTObject):
         self._entity_scope = value
 
     
+    @property
+    def creation_date(self):
+        """ Get creation_date value.
+
+            Notes:
+                Time stamp when this object was created.
+
+                
+                This attribute is named `creationDate` in VSD API.
+                
+        """
+        return self._creation_date
+
+    @creation_date.setter
+    def creation_date(self, value):
+        """ Set creation_date value.
+
+            Notes:
+                Time stamp when this object was created.
+
+                
+                This attribute is named `creationDate` in VSD API.
+                
+        """
+        self._creation_date = value
+
+    
     @property
     def assoc_entity_type(self):
         """ Get assoc_entity_type value.
@@ -500,6 +568,56 @@ class NUEgressProfile(NURESTObject):
         self._associated_sap_egress_qo_s_profile_name = value
 
     
+    @property
+    def customer_id(self):
+        """ Get customer_id value.
+
+            Notes:
+                The customer ID given to parent enterprise. This is used by Netconf/Config manager.
+
+                
+                This attribute is named `customerID` in VSD API.
+                
+        """
+        return self._customer_id
+
+    @customer_id.setter
+    def customer_id(self, value):
+        """ Set customer_id value.
+
+            Notes:
+                The customer ID given to parent enterprise. This is used by Netconf/Config manager.
+
+                
+                This attribute is named `customerID` in VSD API.
+                
+        """
+        self._customer_id = value
+
+    
+    @property
+    def owner(self):
+        """ Get owner value.
+
+            Notes:
+                Identifies the user that has created this object.
+
+                
+        """
+        return self._owner
+
+    @owner.setter
+    def owner(self, value):
+        """ Set owner value.
+
+            Notes:
+                Identifies the user that has created this object.
+
+                
+        """
+        self._owner = value
+
+    
     @property
     def external_id(self):
         """ Get external_id value.
