@@ -112,6 +112,7 @@ class NUGatewayRedundantPort(NURESTObject):
         self._name = None
         self._last_updated_by = None
         self._last_updated_date = None
+        self._native_vlan = None
         self._permitted_action = None
         self._description = None
         self._physical_name = None
@@ -132,6 +133,7 @@ class NUGatewayRedundantPort(NURESTObject):
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="last_updated_date", remote_name="lastUpdatedDate", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="native_vlan", remote_name="nativeVLAN", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="permitted_action", remote_name="permittedAction", attribute_type=str, is_required=False, is_unique=False, choices=[u'ALL', u'DEPLOY', u'EXTEND', u'INSTANTIATE', u'READ', u'USE'])
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="physical_name", remote_name="physicalName", attribute_type=str, is_required=True, is_unique=False)
@@ -278,6 +280,33 @@ class NUGatewayRedundantPort(NURESTObject):
         self._last_updated_date = value
 
     
+    @property
+    def native_vlan(self):
+        """ Get native_vlan value.
+
+            Notes:
+                Default Native VLAN to carry untagged traffic on the redundant ports of this redundant gateway group. Applicable for Cisco 9K only. Possible values are 1-3967.
+
+                
+                This attribute is named `nativeVLAN` in VSD API.
+                
+        """
+        return self._native_vlan
+
+    @native_vlan.setter
+    def native_vlan(self, value):
+        """ Set native_vlan value.
+
+            Notes:
+                Default Native VLAN to carry untagged traffic on the redundant ports of this redundant gateway group. Applicable for Cisco 9K only. Possible values are 1-3967.
+
+                
+                This attribute is named `nativeVLAN` in VSD API.
+                
+        """
+        self._native_vlan = value
+
+    
     @property
     def permitted_action(self):
         """ Get permitted_action value.
