@@ -28,6 +28,9 @@
 
 
 
+from .fetchers import NUPermissionsFetcher
+
+
 from .fetchers import NUMetadatasFetcher
 
 
@@ -89,6 +92,7 @@ class NUPermission(NURESTObject):
         
         self._name = None
         self._last_updated_by = None
+        self._last_updated_date = None
         self._permitted_action = None
         self._permitted_enterprise_description = None
         self._permitted_enterprise_name = None
@@ -97,16 +101,19 @@ class NUPermission(NURESTObject):
         self._permitted_entity_type = None
         self._embedded_metadata = None
         self._entity_scope = None
+        self._creation_date = None
         self._associated_group_description = None
         self._associated_group_id = None
         self._associated_group_name = None
         self._associated_role_description = None
         self._associated_role_id = None
         self._associated_role_name = None
+        self._owner = None
         self._external_id = None
         
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="last_updated_date", remote_name="lastUpdatedDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="permitted_action", remote_name="permittedAction", attribute_type=str, is_required=False, is_unique=False, choices=[u'ALL', u'DEPLOY', u'EXTEND', u'INSTANTIATE', u'READ', u'USE'])
         self.expose_attribute(local_name="permitted_enterprise_description", remote_name="permittedEnterpriseDescription", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="permitted_enterprise_name", remote_name="permittedEnterpriseName", attribute_type=str, is_required=False, is_unique=False)
@@ -115,18 +122,23 @@ class NUPermission(NURESTObject):
         self.expose_attribute(local_name="permitted_entity_type", remote_name="permittedEntityType", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="embedded_metadata", remote_name="embeddedMetadata", attribute_type=list, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
+        self.expose_attribute(local_name="creation_date", remote_name="creationDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_group_description", remote_name="associatedGroupDescription", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_group_id", remote_name="associatedGroupID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_group_name", remote_name="associatedGroupName", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_role_description", remote_name="associatedRoleDescription", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_role_id", remote_name="associatedRoleID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_role_name", remote_name="associatedRoleName", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="owner", remote_name="owner", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         
 
         # Fetchers
         
         
+        self.permissions = NUPermissionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -190,6 +202,33 @@ class NUPermission(NURESTObject):
         self._last_updated_by = value
 
     
+    @property
+    def last_updated_date(self):
+        """ Get last_updated_date value.
+
+            Notes:
+                Time stamp when this object was last updated.
+
+                
+                This attribute is named `lastUpdatedDate` in VSD API.
+                
+        """
+        return self._last_updated_date
+
+    @last_updated_date.setter
+    def last_updated_date(self, value):
+        """ Set last_updated_date value.
+
+            Notes:
+                Time stamp when this object was last updated.
+
+                
+                This attribute is named `lastUpdatedDate` in VSD API.
+                
+        """
+        self._last_updated_date = value
+
+    
     @property
     def permitted_action(self):
         """ Get permitted_action value.
@@ -406,6 +445,33 @@ class NUPermission(NURESTObject):
         self._entity_scope = value
 
     
+    @property
+    def creation_date(self):
+        """ Get creation_date value.
+
+            Notes:
+                Time stamp when this object was created.
+
+                
+                This attribute is named `creationDate` in VSD API.
+                
+        """
+        return self._creation_date
+
+    @creation_date.setter
+    def creation_date(self, value):
+        """ Set creation_date value.
+
+            Notes:
+                Time stamp when this object was created.
+
+                
+                This attribute is named `creationDate` in VSD API.
+                
+        """
+        self._creation_date = value
+
+    
     @property
     def associated_group_description(self):
         """ Get associated_group_description value.
@@ -568,6 +634,29 @@ class NUPermission(NURESTObject):
         self._associated_role_name = value
 
     
+    @property
+    def owner(self):
+        """ Get owner value.
+
+            Notes:
+                Identifies the user that has created this object.
+
+                
+        """
+        return self._owner
+
+    @owner.setter
+    def owner(self, value):
+        """ Set owner value.
+
+            Notes:
+                Identifies the user that has created this object.
+
+                
+        """
+        self._owner = value
+
+    
     @property
     def external_id(self):
         """ Get external_id value.
